@@ -1,8 +1,10 @@
-# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MIT
 
-from __future__ import absolute_import, division, print_function
+"""
+The secure Argon2 password hashing algorithm.
+"""
 
-from . import exceptions, low_level
+from . import exceptions, low_level, profiles
 from ._legacy import hash_password, hash_password_raw, verify_password
 from ._password_hasher import (
     DEFAULT_HASH_LENGTH,
@@ -16,13 +18,12 @@ from ._utils import Parameters, extract_parameters
 from .low_level import Type
 
 
-__version__ = "20.1.0"
+__version__ = "21.3.0"
 
 __title__ = "argon2-cffi"
-__description__ = "The secure Argon2 password hashing algorithm."
+__description__ = (__doc__ or "").strip()
 __url__ = "https://argon2-cffi.readthedocs.io/"
 __uri__ = __url__
-__doc__ = __description__ + " <" + __url__ + ">"
 
 __author__ = "Hynek Schlawack"
 __email__ = "hs@ox.cx"
@@ -45,5 +46,6 @@ __all__ = [
     "hash_password",
     "hash_password_raw",
     "low_level",
+    "profiles",
     "verify_password",
 ]
